﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace RadDataForm_DataFormComboBoxField_SL
{
	/// <summary>
	/// A football club.
	/// </summary>
	public class Club : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string name;
		private DateTime established;
		private int stadiumCapacity;
		private ObservableCollection<Player> players;
		private int id;
		public int ID
		{
			get
			{
				return this.id;
			}
			set
			{
				if (this.id != value)
				{
					this.id = value;
					this.OnPropertyChanged("ID");
				}
			}
		}

		private bool isChampion;
		public bool IsChampion
		{
			get
			{
				return this.isChampion;
			}
			set
			{
				if (this.isChampion != value)
				{
					this.isChampion = value;
					this.OnPropertyChanged("IsChampion");
				}
			}
		}
		
		
		public string Name
		{
			get { return this.name; }
			set
			{
				if (value != this.name)
				{
					this.name = value;
					this.OnPropertyChanged("Name");
				}
			}
		}

		public DateTime Established
		{
			get { return this.established; }
			set
			{
				if (value != this.established)
				{
					this.established = value;
					this.OnPropertyChanged("Established");
				}
			}
		}

		public int StadiumCapacity
		{
			get { return this.stadiumCapacity; }
			set
			{
				if (value != this.stadiumCapacity)
				{
					this.stadiumCapacity = value;
					this.OnPropertyChanged("StadiumCapacity");
				}
			}
		}

		public ObservableCollection<Player> Players
		{
			get
			{
				if (null == this.players)
				{
					this.players = new ObservableCollection<Player>();
				}

				return this.players;
			}
		}

		public Club()
		{

		}

		public Club(string name, DateTime established, int stadiumCapacity, int id, bool isChampion)
		{
			this.name = name;
			this.established = established;
			this.stadiumCapacity = stadiumCapacity;
			this.id = id;
			this.isChampion = isChampion;
		}

		public Club(string name, DateTime established, int stadiumCapacity,int id, bool isChampion, ObservableCollection<Player> players)
			: this(name, established, stadiumCapacity, id, isChampion)
		{
			this.players = players;
		}

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return this.Name;
		}

		public static ObservableCollection<Club> GetClubs()
		{
			ObservableCollection<Club> clubs = new ObservableCollection<Club>();
			Club club;

			// Liverpool
			club = new Club("Liverpool", new DateTime(1892, 1, 1), 45362, 1, true);
			club.Players.Add(new Player("Pepe Reina", 25, Position.GK, "Spain", 1));
			club.Players.Add(new Player("Jamie Carragher", 23, Position.DF, "England", 1));
			club.Players.Add(new Player("Steven Gerrard", 8, Position.MF, "England", 1));
			club.Players.Add(new Player("Fernando Torres", 9, Position.FW, "Spain", 1));
			clubs.Add(club);

			// Manchester Utd.
			club = new Club("Manchester Utd.", new DateTime(1878, 1, 1), 76212, 2, true);
			club.Players.Add(new Player("Edwin van der Sar", 1, Position.GK, "Netherlands", 2));
			club.Players.Add(new Player("Rio Ferdinand", 5, Position.DF, "England", 2));
			club.Players.Add(new Player("Ryan Giggs", 11, Position.MF, "Wales", 2));
			club.Players.Add(new Player("Wayne Rooney", 10, Position.FW, "England", 2));
			clubs.Add(club);

			// Chelsea
			club = new Club("Chelsea", new DateTime(1905, 1, 1), 42055, 3, false);
			club.Players.Add(new Player("Petr Čech", 1, Position.GK, "Czech Republic", 3));
			club.Players.Add(new Player("John Terry", 26, Position.DF, "England", 3));
			club.Players.Add(new Player("Frank Lampard", 8, Position.MF, "England", 3));
			club.Players.Add(new Player("Nicolas Anelka", 39, Position.FW, "France", 3));
			clubs.Add(club);

			// Arsenal
			club = new Club("Arsenal", new DateTime(1886, 1, 1), 60355, 4,false);
			club.Players.Add(new Player("Manuel Almunia", 1, Position.GK, "Spain", 4));
			club.Players.Add(new Player("Gaël Clichy", 22, Position.DF, "France", 4));
			club.Players.Add(new Player("Cesc Fàbregas", 4, Position.MF, "Spain", 4));
			club.Players.Add(new Player("Robin van Persie", 11, Position.FW, "Netherlands", 4));
			clubs.Add(club);

			return clubs;
		}
	}
}
